PyTelegramBotApi MiniApp

client buttons

hapticFeedback (notification)

tweak color [Bot API 6.1+]

Header color:

Background color:

popup and alert [Bot API 6.2+]

request [Bot API 6.9+]

story [Bot API 7.8+]

cloud storage [Bot API 6.9+]

key | value
--- | ---
- | -

data from telegram

initDataUnsafe

ThemeParams

Biometrics Manager

support | Unsupported in this platform

event from telegram

vertical scroll behaviour [Bot API 7.7+]

close the miniapp when scroll vertically

closing confirmation [Bot API 6.2+]

Confimation dialog when closing miniapp

links

- pyTelegramBotApi - opens telegram link in telegram

- Telegram - opens link inside telegram in browser.

other

     version:

     platform:

     color scheme: